"""
Github page: https://github.com/spring-haru/wooldridge
"""

from .load_data import *

__all__ = ['data', 'dataWoo']

__author__ = 'Tetsu Haruyama'
__version__ = '0.4.5'
__copyright__ = 'Copyright (c) 2024 Tetsu Haruyama'
